<?php

namespace FiloBlu\DynamicCustomOptions\Block\Adminhtml\DynamicCustomOptions;

class Edit extends \Magento\Backend\Block\Widget\Form\Container
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $coreRegistry = null;

    /**
     * @param \Magento\Backend\Block\Widget\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Widget\Context $context,
        \Magento\Framework\Registry $registry,
        array $data = []
    ) {
        $this->coreRegistry = $registry;
        parent::__construct($context, $data);
    }

    /**
     * Initialize form
     * Add standard buttons
     * Add "Save and Continue" button
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_objectId = 'id';
        $this->_controller = 'adminhtml_dynamiccustomoptions';
        $this->_blockGroup = 'FiloBlu_DynamicCustomOptions';

        parent::_construct();

        $this->buttonList->add(
            'save_and_continue_edit',
            [
                'class' => 'save',
                'label' => __('Save and Continue Edit'),
                'data_attribute' => [
                    'mage-init' => ['button' => ['event' => 'saveAndContinueEdit', 'target' => '#edit_form']],
                ]
            ],
            10
        );
    }

    /**
     * Getter for form header text
     *
     * @return \Magento\Framework\Phrase
     */
    public function getHeaderText()
    {
        $dynamicCustomOptions = $this->coreRegistry->registry('current_dynamiccustomoptions');
        if ($dynamicCustomOptions->getDynamiccustomoptionsId()) {
            return __("Edit Dynamic Custom Options '%1'", $this->escapeHtml($dynamicCustomOptions->getName()));
        } else {
            return __('New Dynamic Custom Options');
        }
    }

}